# Changelog

## [0.0.6] - 2023-08-04
### Added
- License file (https://github.com/stenson/b3denv/pull/1)

## [0.0.9] - 2023-09-25
### Modified
- `b3denv blender` and `b3denv bpy` have become `b3denv print blender` and `b3denv print python`
- `b3denv blender` and `b3denv python` now run their respective executables with no arguments (all other arguments are passed directly to those executables)

## [0.0.10] - 2024-01-19
### Fixed
- Accept 4 as a valid Blender version

## [0.0.11] - 2024-01-30
### Fixed
- Accept 4 as valid Blender version on win
- Cleaned up a bunch of stuff

## [0.0.12] - 2024-01-31
### Fixed
- Use uninstall code to uninstall before install 

## [0.0.20] - 2025-04-01
### Fixed
- Create target dir on install for non-windows

## [0.0.21] - 2026-01-15
- Accept 5 as a valid Blender version
- Give up on Python 2 support, because...
- Start using uv (omg so much better)